# MMA—Musical MIDI Accompaniment

This is a fork from [MMA](https://www.mellowood.ca/mma/) to make it available as a pip module.
The current version of MMA in this project is 20.02, which can be different from the main repository.
